# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class Code:
    SUCCESS = 1
    DATA_PENDING_SYNC = 2
    ADDRESS_FORMAT_ERROR = 2004
    CHAIN_NOT_SUPPORTED = 2018
    NON_CONTRACT_ADDRESS = 2020
    CONTRACT_INFO_NOT_FOUND = 2021
    DAPP_NOT_FOUND = 2026
    ABI_NOT_FOUND = 2027
    ABI_FUNCTION_UNSUPPOERT = 2028
    APP_KEY_NOT_EXIST = 4010
    SIGNATURE_EXPIRATION = 4011
    SIGNATURE_VERIFICATION_FAILURE = 4012
    FREQUENCY_OVER_LIMIT = 4029
    INVALID_TOKEN = 4022
    TOKEN_NOT_FOUND = 4023
    SERVER_ERROR = 5000
    PARAM_ERROR = 5006
