# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from swagger_client.api.token_controller_v_1_api import TokenControllerV1Api


class Chain(object):
    """
    Supported Blockchains
    """

    @classmethod
    def get_chain_list(cls, **kwargs):
        return TokenControllerV1Api().get_chains_list_using_get(**kwargs)
